"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Carousel = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _flashList = require("@shopify/flash-list");
var _utils = require("./utils");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const {
  width
} = _reactNative.Dimensions.get('screen');
const AUTO_SCROLL_PAUSE = 5;
const AUTO_SCROLL_INTERVAL = 5;
const Carousel = exports.Carousel = /*#__PURE__*/_react.default.memo(_ref => {
  let {
    data,
    autoScroll: autoScrollProp = false,
    autoScrollInterval = AUTO_SCROLL_INTERVAL,
    autoScrollPause = AUTO_SCROLL_PAUSE,
    ...flashListRestProps
  } = _ref;
  const carouselRef = (0, _react.useRef)(null);
  const userTouchTimerRef = (0, _react.useRef)();
  const autoScrollTimerRef = (0, _react.useRef)();
  const [autoScroll, setAutoScroll] = (0, _react.useState)(autoScrollProp);
  const [visibleItemIndex, setVisibleItemIndex] = (0, _react.useState)(0);
  const handleUserAnyTouch = (0, _react.useCallback)(() => {
    if (autoScrollProp) {
      clearTimeout(autoScrollTimerRef.current);
      clearTimeout(userTouchTimerRef.current);
      setAutoScroll(false);
      userTouchTimerRef.current = setTimeout(() => {
        setAutoScroll(true);
      }, autoScrollPause * 1000);
    }
  }, [autoScrollPause, autoScrollProp]);
  const handleViewableItemsChanged = (0, _react.useCallback)(_ref2 => {
    var _viewableItems$;
    let {
      viewableItems
    } = _ref2;
    const firstVisibleItemIndex = viewableItems === null || viewableItems === void 0 || (_viewableItems$ = viewableItems[0]) === null || _viewableItems$ === void 0 ? void 0 : _viewableItems$.index;
    const lastDataIndex = ((data === null || data === void 0 ? void 0 : data.length) ?? 0) - 1;
    if (firstVisibleItemIndex === lastDataIndex) {
      setAutoScroll(false);
    }
    if (typeof firstVisibleItemIndex === 'number') {
      setVisibleItemIndex(firstVisibleItemIndex);
    }
  }, [data === null || data === void 0 ? void 0 : data.length]);
  (0, _react.useEffect)(() => {
    if (autoScrollProp && autoScroll) {
      const nextItemIndex = visibleItemIndex + 1;
      const hasNextItem = (0, _utils.checkIfItemExists)(data === null || data === void 0 ? void 0 : data[nextItemIndex]);
      if (hasNextItem) {
        autoScrollTimerRef.current = setTimeout(() => {
          var _carouselRef$current;
          (_carouselRef$current = carouselRef.current) === null || _carouselRef$current === void 0 || _carouselRef$current.scrollToIndex({
            index: nextItemIndex,
            animated: true
          });
        }, autoScrollInterval * 1000);
      }
    }
  }, [autoScroll, autoScrollInterval, autoScrollProp, data, visibleItemIndex]);
  (0, _react.useEffect)(() => () => {
    clearTimeout(userTouchTimerRef.current);
    clearTimeout(autoScrollTimerRef.current);
  }, []);
  return /*#__PURE__*/_react.default.createElement(_flashList.FlashList, _extends({
    decelerationRate: 'fast',
    estimatedItemSize: width,
    showsHorizontalScrollIndicator: false
  }, flashListRestProps, {
    onViewableItemsChanged: handleViewableItemsChanged,
    onTouchStart: handleUserAnyTouch,
    ref: carouselRef,
    pagingEnabled: true,
    data: data,
    horizontal: true
  }));
});
//# sourceMappingURL=Carousel.js.map