function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React, { useRef, useState, useEffect, useCallback } from 'react';
import { Dimensions } from 'react-native';
import { FlashList } from '@shopify/flash-list';
import { checkIfItemExists } from './utils';
const {
  width
} = Dimensions.get('screen');
const AUTO_SCROLL_PAUSE = 5;
const AUTO_SCROLL_INTERVAL = 5;
export const Carousel = /*#__PURE__*/React.memo(_ref => {
  let {
    data,
    autoScroll: autoScrollProp = false,
    autoScrollInterval = AUTO_SCROLL_INTERVAL,
    autoScrollPause = AUTO_SCROLL_PAUSE,
    ...flashListRestProps
  } = _ref;
  const carouselRef = useRef(null);
  const userTouchTimerRef = useRef();
  const autoScrollTimerRef = useRef();
  const [autoScroll, setAutoScroll] = useState(autoScrollProp);
  const [visibleItemIndex, setVisibleItemIndex] = useState(0);
  const handleUserAnyTouch = useCallback(() => {
    if (autoScrollProp) {
      clearTimeout(autoScrollTimerRef.current);
      clearTimeout(userTouchTimerRef.current);
      setAutoScroll(false);
      userTouchTimerRef.current = setTimeout(() => {
        setAutoScroll(true);
      }, autoScrollPause * 1000);
    }
  }, [autoScrollPause, autoScrollProp]);
  const handleViewableItemsChanged = useCallback(_ref2 => {
    var _viewableItems$;
    let {
      viewableItems
    } = _ref2;
    const firstVisibleItemIndex = viewableItems === null || viewableItems === void 0 || (_viewableItems$ = viewableItems[0]) === null || _viewableItems$ === void 0 ? void 0 : _viewableItems$.index;
    const lastDataIndex = ((data === null || data === void 0 ? void 0 : data.length) ?? 0) - 1;
    if (firstVisibleItemIndex === lastDataIndex) {
      setAutoScroll(false);
    }
    if (typeof firstVisibleItemIndex === 'number') {
      setVisibleItemIndex(firstVisibleItemIndex);
    }
  }, [data === null || data === void 0 ? void 0 : data.length]);
  useEffect(() => {
    if (autoScrollProp && autoScroll) {
      const nextItemIndex = visibleItemIndex + 1;
      const hasNextItem = checkIfItemExists(data === null || data === void 0 ? void 0 : data[nextItemIndex]);
      if (hasNextItem) {
        autoScrollTimerRef.current = setTimeout(() => {
          var _carouselRef$current;
          (_carouselRef$current = carouselRef.current) === null || _carouselRef$current === void 0 || _carouselRef$current.scrollToIndex({
            index: nextItemIndex,
            animated: true
          });
        }, autoScrollInterval * 1000);
      }
    }
  }, [autoScroll, autoScrollInterval, autoScrollProp, data, visibleItemIndex]);
  useEffect(() => () => {
    clearTimeout(userTouchTimerRef.current);
    clearTimeout(autoScrollTimerRef.current);
  }, []);
  return /*#__PURE__*/React.createElement(FlashList, _extends({
    decelerationRate: 'fast',
    estimatedItemSize: width,
    showsHorizontalScrollIndicator: false
  }, flashListRestProps, {
    onViewableItemsChanged: handleViewableItemsChanged,
    onTouchStart: handleUserAnyTouch,
    ref: carouselRef,
    pagingEnabled: true,
    data: data,
    horizontal: true
  }));
});
//# sourceMappingURL=Carousel.js.map